using System;
using System.Threading;
using System.Collections;

using Syncfusion.Windows.Forms.Grid;


namespace GridUpdates
{
	public delegate void DelegateRefreshRows(GridRangeInfo updateRange);
	public class WorkerThread
	{
		Form1 _form;
		private System.Random _rand;
		private int _sleepTime;
		private int [,]_data;

		DelegateRefreshRows _refreshRows;

		public WorkerThread(Form1 f, int rows, int cols)
		{
			_form = f;
			_refreshRows = new DelegateRefreshRows(_form.RefreshRows);

			_rand = new Random();
			_sleepTime = 3000;

			_data = new int[rows, cols];
			for(int i = 0; i < rows; i++)
				for(int j = 0; j < cols; j++)
					_data[i, j] = _rand.Next(1000);
		}

		public int Rows
		{
			get { return _data.GetLength(0); }
		}

		public int Cols
		{
			get { return _data.GetLength(1); }
		}

		public int this[int cell_row, int cell_col]
		{
			get
			{
				return _data[cell_row-1, cell_col-1];
			}
		}

		public int SleepTime
		{
			get { return _sleepTime; } 
			set { _sleepTime = value; } 
		}

		public void Runner()
		{
			while(true)
			{
				int max_updates = 100;
				GridRangeInfo updateRange = GridRangeInfo.Empty;
				for(int row = 0; row < max_updates; row++)
				{
					
					int randomRow = _rand.Next(this.Rows); // Choose a Random Row
					for(int col = 0; col < this.Cols; col++) // Update all Cols in that Row
						_data[randomRow, col] = _rand.Next(1000);

					GridRangeInfo range = GridRangeInfo.Row(randomRow);
					updateRange = updateRange.UnionRange(range);
				}		
				_form.Invoke(this._refreshRows, new object[]{updateRange});
		
			}
		}

	}
}
